@@ -1,7 +1,7 @@
 // qjackctlGraph.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -408,6 +408,9 @@ public:
 	void setPort2(qjackctlGraphPort *port);
 	qjackctlGraphPort *port2() const;
 
+	// Active disconnection.
+	void disconnect();
+
 	// Path/shaper updaters.
 	void updatePathTo(const QPointF& pos);
 	void updatePath();
@@ -489,6 +492,9 @@ public:
 	qjackctlGraphNode *findNode(
 		const QString& name, qjackctlGraphItem::Mode mode, uint type = 0) const;
 
+	// Whether it's in the middle of something...
+	bool isBusy() const;
+
 	// Port (dis)connections notifiers.
 	void emitConnected(qjackctlGraphPort *port1, qjackctlGraphPort *port2);
 	void emitDisconnected(qjackctlGraphPort *port1, qjackctlGraphPort *port2);
